unit MainUnit;

interface

uses
  Windows,
  Messages,
  SysUtils,
  Classes,
  Graphics,
  Controls,
  Forms,
  Dialogs,
  ExtCtrls,
  ComCtrls,
  StdCtrls,
  Buttons,
  Grids,
  DBGrids,
  DBCtrls,
  Menus,
  Db,
  BDE,
  jpeg,
  GIFImage,
  DBTables,
  ExtDlgs,
  Shellapi,
  ActiveX,
  ShlObj,
  IniFiles,
  Clipbrd;

type
  TfrmPictCollector = class(TForm)
    pnlLeft: TPanel;
    pnlLeftTop: TPanel;
    splitVert: TSplitter;
    pnlBottom: TPanel;
    btnQuit: TButton;
    btnHelp: TButton;
    StatusBar: TStatusBar;
    Image1: TImage;
    splitHoriz: TSplitter;
    DBGrid1: TDBGrid;
    DBNavigator1: TDBNavigator;
    PopupMenu1: TPopupMenu;
    NewCollection1: TMenuItem;
    RenameCollection1: TMenuItem;
    RemoveCollection1: TMenuItem;
    Table1: TTable;
    DataSource1: TDataSource;
    Table1FileName: TStringField;
    Table1FileSize: TIntegerField;
    Table1FileType: TStringField;
    Table1PictureBLOB: TBlobField;
    N1: TMenuItem;
    InsertPicture1: TMenuItem;
    RemovePicture1: TMenuItem;
    Table1Category: TStringField;
    OpenPictureDialog: TOpenPictureDialog;
    pnlRight: TPanel;
    imgPreview: TImage;
    pnlRightBottom: TPanel;
    chkTransparent: TCheckBox;
    chkStretch: TCheckBox;
    Table1PictureSize: TStringField;
    Table1fmtFileSize: TFloatField;
    Savetofile1: TMenuItem;
    Copytoclipboard1: TMenuItem;
    SavePictureDialog: TSavePictureDialog;
    CreateCollectionfromfolder1: TMenuItem;
    N2: TMenuItem;
    btnAbout: TButton;
    pnlNav: TPanel;
    btnUp: TSpeedButton;
    btnDown: TSpeedButton;
    PageScroller1: TPageScroller;
    tabCollectionItems: TTabControl;
    procedure tabCollectionItemsResize(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure NewCollection1Click(Sender: TObject);
    procedure RemoveCollection1Click(Sender: TObject);
    procedure btnQuitClick(Sender: TObject);
    procedure tabCollectionItemsChange(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure PopupMenu1Popup(Sender: TObject);
    procedure InsertPicture1Click(Sender: TObject);
    procedure chkTransparentClick(Sender: TObject);
    procedure DBGrid1CellClick(Column: TColumn);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure Table1CalcFields(DataSet: TDataSet);
    procedure RemovePicture1Click(Sender: TObject);
    procedure Table1BeforeDelete(DataSet: TDataSet);
    procedure Savetofile1Click(Sender: TObject);
    procedure Copytoclipboard1Click(Sender: TObject);
    procedure Table1AfterScroll(DataSet: TDataSet);
    procedure DBNavigator1Click(Sender: TObject; Button: TNavigateBtn);
    procedure CreateCollectionfromfolder1Click(Sender: TObject);
    procedure btnAboutClick(Sender: TObject);
    procedure btnUpClick(Sender: TObject);
    procedure btnDownClick(Sender: TObject);
    procedure pnlNavResize(Sender: TObject);
  private
    YesToAll: Boolean;
    Deleting: Boolean;
    procedure InsertNewFile(FileName: string; Category: string);
    procedure SaveToFile(FileName: string);
    procedure DoPreview;
    procedure ShowHint(Sender: TObject);
    procedure SetLastUsedPath(Path: string);
    function GetLastUsedPath: string;
    procedure CopyToClipboard;
    procedure CreateCollectionFromFolder(Dir: string);
    procedure WMDropFiles(var Msg: TWMDropFiles); message WM_DROPFILES;
    procedure AppOnMessage(var Msg: TMsg; var Handled: Boolean);
  public
    { Public declarations }
  end;

var
  frmPictCollector  : TfrmPictCollector;
const
  GraphFileExt      : array[0..6] of string = ('.gif', '.jpg', '.jpeg', '.bmp', '.ico', '.emf', '.wmf');

implementation

uses NewCollectionDlg;

{$R *.DFM}

function SlashSep(const Path, S: string): string;
begin
  if AnsiLastChar(Path)^ <> '\' then
    Result := Path + '\' + S
  else
    Result := Path + S;
end;

function directoryexists(const Name: string): Boolean;
var
  Code              : Integer;
begin
  Code := GetFileAttributes(PChar(Name));
  Result := (Code <> -1) and (FILE_ATTRIBUTE_DIRECTORY and Code <> 0);
end;

function SelectDirectory(const Caption: string; const Root: WideString;
  out Directory: string): Boolean;
var
  WindowList        : Pointer;
  BrowseInfo        : TBrowseInfo;
  Buffer            : PChar;
  RootItemIDList, ItemIDList: PItemIDList;
  ShellMalloc       : IMalloc;
  IDesktopFolder    : IShellFolder;
  Eaten, Flags      : Longword;
begin
  Result := False;
  Directory := '';
  FillChar(BrowseInfo, SizeOf(BrowseInfo), 0);
  if (ShGetMalloc(ShellMalloc) = S_OK) and (ShellMalloc <> nil) then
    begin
      Buffer := ShellMalloc.Alloc(MAX_PATH);
      try
        RootItemIDList := nil;
        if Root <> '' then
          begin
            SHGetDesktopFolder(IDesktopFolder);
            IDesktopFolder.ParseDisplayName(Application.Handle, nil,
              POleStr(Root), Eaten, RootItemIDList, Flags);
          end;
        with BrowseInfo do
          begin
            hwndOwner := Application.Handle;
            pidlRoot := RootItemIDList;
            pszDisplayName := Buffer;
            lpszTitle := PChar(Caption);
            ulFlags := BIF_RETURNONLYFSDIRS;
          end;
        WindowList := DisableTaskWindows(0);
        try
          ItemIDList := ShBrowseForFolder(BrowseInfo);
        finally
          EnableTaskWindows(WindowList);
        end;
        Result := ItemIDList <> nil;
        if Result then
          begin
            ShGetPathFromIDList(ItemIDList, Buffer);
            ShellMalloc.Free(ItemIDList);
            Directory := Buffer;
          end;
      finally
        ShellMalloc.Free(Buffer);
      end;
    end;
end;

procedure PackTable(Table: TTable);
var
  Props             : CURProps;
  hDb               : hDbiDb;
  TableDesc         : CRTblDesc;
begin
  if not Table.Active then
    raise EDatabaseError.Create('Table must be opened to pack');
  if not Table.Exclusive then
    raise EDatabaseError.Create('Table must be opened exclusively to pack');
  Check(DbiGetCursorProps(Table.Handle, Props));
  if Props.szTableType = szPARADOX then
    begin
      FillChar(TableDesc, SizeOf(TableDesc), 0);
      Check(DbiGetObjFromObj(hDBIObj(Table.Handle), objDATABASE, hDBIObj(hDb)));
      StrPCopy(TableDesc.szTblName, Table.TableName);
      StrPCopy(TableDesc.szTblType, Props.szTableType);
      TableDesc.bPack := True;
      Table.Close;
      Check(DbiDoRestructure(hDb, 1, @TableDesc, nil, nil, nil, False));
    end
  else
    if (Props.szTableType = szDBASE) then
    Check(DbiPackTable(Table.dbhandle, Table.Handle, nil, szDBASE, True))
  else
    raise EDatabaseError.Create('Table must be either of Paradox or dBASE type to pack');
  Table.Open;
end;

procedure TfrmPictCollector.InsertNewFile(FileName: string; Category: string);
var
  Info              : tshfileinfo;
  R                 : TSearchRec;
  Size              : Integer;
  MemStream         : TMemoryStream;
  S                 : TStream;
  tmpPict           : TPicture;
  PictSize          : string;
  FileFound         : Boolean;
begin
  try
    FileFound := Table1.FindKey([ExtractFileName(FileName), Category]);
    shgetfileinfo(PAnsiChar(FileName), 0, Info, SizeOf(Info), shgfi_displayname or shgfi_typename or shgfi_icon or shgfi_attributes);
    if FindFirst(FileName, faAnyFile, R) = 0 then
      Size := R.Size
    else
      Size := 0;

    tmpPict := TPicture.Create;
    try
      tmpPict.LoadFromFile(FileName);
      PictSize := Format('%d x %d', [tmpPict.Width, tmpPict.Height]);
    finally
      tmpPict.Free;
    end;
    if not FileFound then
      Table1.AppendRecord([ExtractFileName(FileName), Category, Info.sztypename, Size, PictSize])
    else
      if MessageBox(0, PChar(Format('File %s already exists. Overwrite?', [FileName])), 'File exists', mb_yesno or MB_ICONQUESTION or MB_TOPMOST) = id_yes then
      begin
        Table1.Edit;
        Table1.FieldByName('FileType').AsString := Info.sztypename;
        Table1.FieldByName('FileSize').AsInteger := Size;
        Table1.FieldByName('PictureSize').AsString := PictSize;
        Table1.Post;
      end;

    Table1.Edit;
    MemStream := TMemoryStream.Create;
    S := Table1.CreateBlobStream(Table1.Fields[5], bmWrite);
    try
      MemStream.LoadFromFile(FileName);
      MemStream.Position := 0;
      S.CopyFrom(MemStream, MemStream.Size);
    finally
      S.Free;
      MemStream.Free;
    end;
    Table1.Post;
  except
  end;
end;

procedure TfrmPictCollector.SaveToFile(FileName: string);
var
  MemStream         : TMemoryStream;
  S                 : TStream;
begin
  if Table1.RecordCount = 0 then
    Exit;
  MemStream := TMemoryStream.Create;
  S := Table1.CreateBlobStream(Table1.Fields[5], bmRead);
  try
    S.Position := 0;
    MemStream.CopyFrom(S, S.Size);
    MemStream.SaveToFile(FileName);
  finally
    S.Free;
    MemStream.Free;
  end;
end;

procedure TfrmPictCollector.DoPreview;
begin
  if Table1.RecordCount = 0 then
    begin
      imgPreview.Picture.Assign(nil);
      Exit;
    end;
  try
    SaveToFile(ExtractFilePath(Application.ExeName) + Table1.FieldByName('FileName').AsString);
    imgPreview.Picture.LoadFromFile(ExtractFilePath(Application.ExeName) + Table1.FieldByName('FileName').AsString);
    DeleteFile(ExtractFilePath(Application.ExeName) + Table1.FieldByName('FileName').AsString);
  except
  end;
end;

procedure TfrmPictCollector.ShowHint(Sender: TObject);
begin
  StatusBar.SimpleText := GetLongHint(Application.Hint);
end;

procedure TfrmPictCollector.SetLastUsedPath(Path: string);
var
  F                 : TIniFile;
begin
  F := TIniFile.Create(ExtractFilePath(Application.ExeName) + 'Settings.ini');
  try
    F.WriteString('Path', 'LastPath', Path);
  finally
    F.Free;
  end;
end;

function TfrmPictCollector.GetLastUsedPath: string;
var
  F                 : TIniFile;
begin
  F := TIniFile.Create(ExtractFilePath(Application.ExeName) + 'Settings.ini');
  try
    Result := F.ReadString('Path', 'LastPath', '');
  finally
    F.Free;
  end;
end;

procedure TfrmPictCollector.CopyToClipboard;
var
  tmpPict           : TPicture;
  AFormat           : Word;
  AData             : THandle;
  APalette          : hpalette;
begin
  SaveToFile(ExtractFilePath(Application.ExeName) + Table1.FieldByName('FileName').AsString);
  tmpPict := TPicture.Create;
  try
    tmpPict.LoadFromFile(ExtractFilePath(Application.ExeName) + Table1.FieldByName('FileName').AsString);
    tmpPict.SaveToClipboardFormat(AFormat, AData, APalette);
    Clipboard.SetAsHandle(AFormat, AData);
  finally
    tmpPict.Free;
  end;
end;

procedure TfrmPictCollector.CreateCollectionFromFolder(Dir: string);
var
  R                 : TSearchRec;
  Found             : Integer;
  FileFound         : Integer;
  RFile             : TSearchRec;
  Count             : Integer;

  function IsGraphicExt(Extension: string): Boolean;
  var
    I               : Integer;
  begin
    for I := 0 to High(GraphFileExt) do
      begin
        Result := StrIComp(PChar(Extension), PChar(GraphFileExt[I])) = 0;
        if Result then Break;
      end;
  end;
begin
  Dir := SlashSep(Dir, '');
  Found := FindFirst(Dir + '*.*', fadirectory, R);
  while Found = 0 do
    begin
      if (R.Name <> '.') and (R.Name <> '..') and directoryexists(Dir + R.Name) then
        begin
          FileFound := FindFirst(SlashSep(Dir + R.Name, '') + '*.*', faAnyFile, RFile);
          Count := 0;
          while FileFound = 0 do
            begin
              if IsGraphicExt(extractfileext(RFile.Name)) then
                begin
                  InsertNewFile(SlashSep(Dir + R.Name, '') + RFile.Name, R.Name);
                  Application.Hint := Format('Inserting file %s...', [SlashSep(Dir + R.Name, '') + RFile.Name]);
                  Inc(Count);
                end;
              FileFound := FindNext(RFile);
            end;
          if Count > 0 then
            tabCollectionItems.Tabs.Add(R.Name);
          CreateCollectionFromFolder(Dir + R.Name);
        end;
      Found := FindNext(R);
    end;
end;

procedure TfrmPictCollector.tabCollectionItemsResize(Sender: TObject);
begin
  tabCollectionItems.TabWidth := PageScroller1.Width - 10;
end;

procedure TfrmPictCollector.FormShow(Sender: TObject);
begin
  tabCollectionItemsResize(Sender);
  tabCollectionItemsChange(Sender);
end;

procedure TfrmPictCollector.NewCollection1Click(Sender: TObject);
var
  Index             : Integer;
  SaveCursor        : TCursor;
begin
  frmNewCollction := TfrmNewCollction.Create(Self);
  try
    with frmNewCollction do
      begin
        if Sender = RenameCollection1 then
          begin
            Caption := 'Rename collection item';
            lblPrompt.Caption := 'Enter the new description of the collection:';
            edtCollectionName.Text := tabCollectionItems.Tabs[tabCollectionItems.TabIndex];
          end;
        Index := tabCollectionItems.Tabs.IndexOf(edtCollectionName.Text);
        if ShowModal = mrOK then
          if tabCollectionItems.Tabs.IndexOf(edtCollectionName.Text) < 0 then
            if Trim(edtCollectionName.Text) <> '' then
              if Sender = RenameCollection1 then
                begin
                  SaveCursor := Screen.Cursor;
                  Screen.Cursor := crHourGlass;
                  Table1.DisableControls;
                  while Table1.RecordCount > 0 do
                    begin
                      Application.Hint := Format('Moving file %s...', [Table1.FieldByName('FileName').AsString]);
                      Table1.Edit;
                      Table1.FieldByName('Category').AsString := edtCollectionName.Text;
                      Table1.Post;
                    end;
                  Table1.EnableControls;
                  Screen.Cursor := SaveCursor;
                  tabCollectionItems.Tabs[Index] := edtCollectionName.Text;
                end
              else
                tabCollectionItems.Tabs.Add(edtCollectionName.Text)
            else
              MessageBox(0, 'Collection name cannot be null. New collection will not be created.', PChar(Application.Title), mb_iconwarning or mb_OK)
          else
            MessageBox(0, 'Collection name is not unique. New collection will not be created.', PChar(Application.Title), mb_iconwarning or mb_OK);
      end;
    tabCollectionItemsChange(Self);
  finally
    frmNewCollction.Free;
  end;
end;

procedure TfrmPictCollector.RemoveCollection1Click(Sender: TObject);
var
  S                 : string;
  SaveCursor        : TCursor;
begin
  S := tabCollectionItems.Tabs[tabCollectionItems.TabIndex];
  if MessageBox(0, PChar(Format('Are you sure you want to Delete collection ''%s''?', [S])), 'Delete collection', MB_ICONQUESTION or mb_yesno) = id_yes then
    begin
      YesToAll := True;
      Deleting := True;
      SaveCursor := Screen.Cursor;
      Screen.Cursor := crHourGlass;
      Table1.DisableControls;
      while Table1.RecordCount > 0 do
        begin
          Application.Hint := Format('Removing file %s...', [Table1.FieldByName('FileName').AsString]);
          Table1.Delete;
        end;
      Application.Hint := 'Packing collection table on progress...';
      PackTable(Table1);
      Table1.EnableControls;
      Screen.Cursor := SaveCursor;
      YesToAll := False;
      Deleting := False;
      tabCollectionItems.Tabs.Delete(tabCollectionItems.Tabs.IndexOf(S));
      tabCollectionItemsChange(Self);
    end;
  if tabCollectionItems.Tabs.Count > 0 then
    tabCollectionItems.TabIndex := 0;
end;

procedure TfrmPictCollector.btnQuitClick(Sender: TObject);
begin
  Close;
end;

procedure TfrmPictCollector.tabCollectionItemsChange(Sender: TObject);
var
  Count             : Integer;
begin
  if Table1.Active then
    begin
      if tabCollectionItems.TabIndex >= 0 then
        Table1.Filter := 'Category=''' + StringReplace(tabCollectionItems.Tabs[tabCollectionItems.TabIndex], '''', '''''', [rfReplaceAll]) + '''';
      Count := Table1.RecordCount;
    end
  else
    begin
      Table1.Filter := '';
      Count := 0;
    end;
  if tabCollectionItems.TabIndex >= 0 then
    pnlLeftTop.Caption := Format('%s [%d Items]', [tabCollectionItems.Tabs[tabCollectionItems.TabIndex], Count])
  else
    pnlLeftTop.Caption := Format('All Items [%d items]', [Count]);
end;

procedure TfrmPictCollector.FormCreate(Sender: TObject);
begin
  DragAcceptFiles(Handle, True);
  DragAcceptFiles(Application.Handle, True);
  Application.OnMessage := AppOnMessage;

  YesToAll := False;
  Deleting := False;
  Application.OnHint := ShowHint;
  if fileexists(ExtractFilePath(Application.ExeName) + 'CatItems.cfg') then
    tabCollectionItems.Tabs.LoadFromFile(ExtractFilePath(Application.ExeName) + 'CatItems.cfg');
  Table1.TableName := ExtractFilePath(Application.ExeName) + 'PictArch.db';
  if not fileexists(Table1.TableName) then
    begin
      Table1.CreateTable;
      Table1.AddIndex('FileName', 'FileName;Category', [ixPrimary]);
    end;
  Table1.Open;
end;

procedure TfrmPictCollector.PopupMenu1Popup(Sender: TObject);
begin
  InsertPicture1.Enabled := (PopupMenu1.PopupComponent is TDBGrid) and (tabCollectionItems.TabIndex >= 0);
  RemovePicture1.Enabled := PopupMenu1.PopupComponent is TDBGrid;
  RenameCollection1.Enabled := tabCollectionItems.TabIndex >= 0;
  RemoveCollection1.Enabled := tabCollectionItems.TabIndex >= 0;
  if Table1.Active then
    begin
      RemovePicture1.Enabled := Table1.RecordCount > 0;
      Savetofile1.Enabled := Table1.RecordCount > 0;
      Copytoclipboard1.Enabled := Table1.RecordCount > 0;
    end
  else
    begin
      RemovePicture1.Enabled := False;
      Savetofile1.Enabled := False;
      Copytoclipboard1.Enabled := False;
    end;
end;

procedure TfrmPictCollector.InsertPicture1Click(Sender: TObject);
var
  I                 : Integer;
  SaveCursor        : TCursor;
begin
  OpenPictureDialog.initialdir := GetLastUsedPath;
  if OpenPictureDialog.Execute then
    begin
      SaveCursor := Screen.Cursor;
      Screen.Cursor := crHourGlass;
      Table1.DisableControls;
      for I := 0 to OpenPictureDialog.files.Count - 1 do
        begin
          InsertNewFile(OpenPictureDialog.files[I], tabCollectionItems.Tabs[tabCollectionItems.TabIndex]);
          Application.Hint := Format('Inserting file %s...', [OpenPictureDialog.files[I]]);
        end;
      Table1.EnableControls;
      SetLastUsedPath(ExtractFilePath(OpenPictureDialog.FileName));
      Screen.Cursor := SaveCursor;
      tabCollectionItemsChange(Sender);
    end;
end;

procedure TfrmPictCollector.chkTransparentClick(Sender: TObject);
begin
  imgPreview.Transparent := chkTransparent.Checked;
  imgPreview.Stretch := chkStretch.Checked;
end;

procedure TfrmPictCollector.DBGrid1CellClick(Column: TColumn);
begin
  DoPreview;
  if Table1.RecordCount > 0 then
    pnlRightBottom.Caption := Format('Picture size: %s', [Table1.FieldByName('PictureSize').AsString])
  else
    pnlRightBottom.Caption := '';
end;

procedure TfrmPictCollector.FormClose(Sender: TObject;
  var Action: TCloseAction);
begin
  tabCollectionItems.Tabs.SaveToFile(ExtractFilePath(Application.ExeName) + 'CatItems.cfg');
end;

procedure TfrmPictCollector.Table1CalcFields(DataSet: TDataSet);
begin
  DataSet.FieldByName('fmtFileSize').AsFloat := DataSet.FieldByName('FileSize').AsInteger / 1024;
end;

procedure TfrmPictCollector.RemovePicture1Click(Sender: TObject);
begin
  Table1.Delete;
  tabCollectionItemsChange(Sender);
end;

procedure TfrmPictCollector.Table1BeforeDelete(DataSet: TDataSet);
begin
  if YesToAll then Exit;
  if MessageBox(0, PChar(Format('Are you sure you want to delete item ''%s''?', [Table1.FieldByName('FileName').AsString])), 'Delete item', MB_ICONQUESTION or mb_yesno) = id_no then
    raise EAbort.Create('Delete canceled.');
end;

procedure TfrmPictCollector.Savetofile1Click(Sender: TObject);
begin
  SavePictureDialog.FileName := Table1.FieldByName('FileName').AsString;
  if SavePictureDialog.Execute then
    SaveToFile(SavePictureDialog.FileName);
end;

procedure TfrmPictCollector.Copytoclipboard1Click(Sender: TObject);
begin
  CopyToClipboard;
end;

procedure TfrmPictCollector.Table1AfterScroll(DataSet: TDataSet);
begin
  if Deleting then Exit;
  DBGrid1CellClick(DBGrid1.Columns[0]);
  DBGrid1.Update;
  imgPreview.Update;
end;

procedure TfrmPictCollector.DBNavigator1Click(Sender: TObject;
  Button: TNavigateBtn);
begin
  tabCollectionItemsChange(Sender);
end;

procedure TfrmPictCollector.CreateCollectionfromfolder1Click(
  Sender: TObject);
var
  Dir               : string;
  SaveCursor        : TCursor;
begin
  SaveCursor := Screen.Cursor;
  Screen.Cursor := crHourGlass;
  Table1.DisableControls;
  if SelectDirectory('Select the Collection folder', '', Dir) then
    CreateCollectionFromFolder(Dir);
  Table1.EnableControls;
  Screen.Cursor := SaveCursor;
end;

procedure TfrmPictCollector.WMDropFiles(var Msg: TWMDropFiles);
var
  n                 : Integer;
  Coord             : TPoint;
  Buffer            : array[0..254] of char;
  Count             : Integer;
  FileName          : string;
  RecInfo           : TSearchRec;
begin
  if tabCollectionItems.TabIndex < 0 then Exit;
  with Msg do
    begin
      DragQueryPoint(Drop, Coord);
      Count := DragQueryFile(Drop, $FFFFFFFF, Buffer, 255);
      if ((Coord.X >= DBGrid1.Left + pnlLeft.Left) and (Coord.X < DBGrid1.Left + pnlLeft.Left + DBGrid1.Width)) and
        ((Coord.Y >= DBGrid1.Top + pnlLeft.Top) and (Coord.Y <= DBGrid1.Top + pnlLeft.Top + DBGrid1.Height)) then
        for n := 0 to Count - 1 do
          begin
            DragQueryFile(Drop, n, Buffer, 255);
            FileName := StrPas(Buffer);
            if FindFirst(FileName, faSysFile + faArchive + faHidden, RecInfo) = 0 then
              InsertNewFile(FileName, tabCollectionItems.Tabs[tabCollectionItems.TabIndex]);
          end;
      DragFinish(Drop);
    end;
end;

procedure TfrmPictCollector.AppOnMessage(var Msg: TMsg; var Handled: Boolean);
var
  WMD               : TWMDropFiles;
begin
  if Msg.Message = WM_DROPFILES then
    begin
      MessageBeep(0);
      WMD.Msg := Msg.Message;
      WMD.Drop := Msg.wParam;
      WMD.unused := Msg.lParam;
      WMD.Result := 0;
      WMDropFiles(WMD);
      Handled := True;
    end;
end;

procedure TfrmPictCollector.btnAboutClick(Sender: TObject);
var
  S                 : string;
const
  CRLF              = #13#10;
  Tab               = #9;
begin
  S := Tab + 'Picture Collector Sample App' + CRLF + Tab + '      Powered by Delphi 5' + CRLF + CRLF + Tab + '        Author: Eugen Mihailescu' + CRLF + Tab + 'Company: EM Quicksoft Romania SRL' + CRLF +
    Tab + '    1999,2000 - All right reserved.' + CRLF + CRLF + 'This sample application is freeware. You are free to share ' + CRLF + 'the source code to developers comunity.';
  MessageBox(0, PChar(S), 'About author...', mb_OK or MB_ICONINFORMATION or MB_TOPMOST);
end;

procedure TfrmPictCollector.btnUpClick(Sender: TObject);
begin
  PageScroller1.Position := PageScroller1.Position - 22;
end;

procedure TfrmPictCollector.btnDownClick(Sender: TObject);
begin
  PageScroller1.Position := PageScroller1.Position + 22;
  ShowMessage(IntToStr(PageScroller1.Position))
end;

procedure TfrmPictCollector.pnlNavResize(Sender: TObject);
begin
  btnUp.Top := 2;
  btnDown.Top := pnlNav.Height - btnDown.Height - 2;
end;

end.

